@@ -9,21 +9,18 @@ use MooseX::Types::Moose qw(Int HashRef);
 
 use Carp;
 use Path::Class;
+use Class::Load;
 use Scalar::Util qw(blessed);
-use Class::Load qw(load_class);
 use IO::Interactive qw(is_interactive);
-
-use Plack::Request;
 use Plack::Middleware::Auth::Basic;
 
-use Pinto;
 use Pinto::Types qw(Dir);
 use Pinto::Constants qw($PINTO_SERVER_DEFAULT_PORT);
-use Pinto::Server::Handler;
+use Pinto::Server::Router;
 
 #-------------------------------------------------------------------------------
 
-our $VERSION = '0.037'; # VERSION
+our $VERSION = '0.042'; # VERSION
 
 #-------------------------------------------------------------------------------
 
@@ -48,10 +45,10 @@ has auth => (
 );
 
 
-has handler => (
+has router => (
     is      => 'ro',
-    isa     => 'Pinto::Server::Handler',
-    builder => '_build_handler',
+    isa     => 'Pinto::Server::Router',
+    default => sub { Pinto::Server::Router->new },
     lazy    => 1,
 );
 
@@ -64,20 +61,11 @@ class_has default_port => (
 );
 
 
-#-------------------------------------------------------------------------------
-
-sub _build_handler {
-    my ($self) = @_;
-
-    return Pinto::Server::Handler->new(root => $self->root);
-}
-
 #-------------------------------------------------------------------------------
 
 sub to_app {
     my ($self) = @_;
 
-    $self->prepare_app;
     my $app = sub { $self->call(@_) };
 
     if (my %auth_options = $self->auth_options) {
@@ -86,8 +74,8 @@ sub to_app {
             or carp 'No auth backend provided!';
 
         my $class = 'Authen::Simple::' . $backend;
-        print "Authenticating using $class\n" if is_interactive();
-        load_class($class);
+        print "Authenticating using $class\n" if is_interactive;
+        Class::Load::load_class($class);
 
         $app = Plack::Middleware::Auth::Basic->wrap($app,
             authenticator => $class->new(%auth_options) );
@@ -98,30 +86,13 @@ sub to_app {
 
 #-------------------------------------------------------------------------------
 
-sub prepare_app {
-
-    my ($self) = @_;
-
-    my $root = $self->root();
-    print "Initializing pinto repository at $root\n" if is_interactive();
-
-    my $pinto  = Pinto->new(root => $self->root);
-    my $result = $pinto->new_batch(noinit => 0)->add_action('Nop')->run_actions;
-    confess $result if not $result->is_success;
-
-    return $self;
-}
-
-#-------------------------------------------------------------------------------
-
 sub call {
     my ($self, $env) = @_;
 
-    my $request  = Plack::Request->new($env);
-    my $response = $self->handler->handle($request);
+    my $response = $self->router->route($env, $self->root);
 
-    $response = $response->finalize()
-        if blessed($response) && $response->can('finalize');
+    $response = $response->finalize
+      if blessed($response) && $response->can('finalize');
 
     return $response;
 }
@@ -143,7 +114,7 @@ Pinto::Server - Web interface to a Pinto repository
 
 =head1 VERSION
 
-version 0.037
+version 0.042
 
 =head1 ATTRIBUTES
 
@@ -160,7 +131,7 @@ the server. One of the options must be 'backend', to specify which
 Authen::Simple:: class to use; the other key/value pairs will be passed as-is
 to the Authen::Simple class.
 
-=head2 handler
+=head2 router
 
 An object that does the L<Pinto::Server::Handler> role.  This object
 will do the work of processing the request and returning a response.
@@ -172,7 +143,7 @@ is a class attribute.
 
 There is nothing to see here.
 
-Look at L<pinto-server> if you want to start the server.
+Look at L<pintod> if you want to start the server.
 
 =head1 SUPPORT
 
